PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/Shaders.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
Shaders.hpp
1
2#ifndef GYM_PCB_UI_SHADERS_H
3#define GYM_PCB_UI_SHADERS_H
4
5#include <QOpenGLFunctions_4_3_Core>
6
7 class Shaders
8{
9public:
10 Shaders();
11 ~Shaders();
12 static Shaders *getInstance() { assert(sInstance); return sInstance; }
13 GLuint load(GLenum type, const std::string &name);
14 bool validate(GLuint) const;
15 void forget(const std::string &name);
16
17private:
18 std::map<std::string, GLuint> mTrove;
19
20 static Shaders *sInstance;
21};
22
23#endif // GYM_PCB_UI_SHADERS_H